/*
   ----------------------------------------------------------------------------
   TestSMTP.prg
   A sample dBL program from 
   The dBASE Book Plus by Kenneth J. Mayer. 
   Program copyright 2015. 
   Permission is granted for use as a learning tool for dBASE Plus.
   Sample from: Chapter 12
        
   This is a program designed to show the absolute basics of using the 
   Catalyst Simple Mail Transfer Protocol ActiveX control that is 
   installed with dBASE Plus 9.x
   
   It requires that you fill in variables noted below. See also the form
      Simple Mail Transfer Example.wfm
   Contained in this folder as well.
   
   It is based on a program by Bernard Mouille posted in the newsgroups.
   ----------------------------------------------------------------------------
*/

// check version of dBASE ...:
if val( right( version(),4) ) < 9
   msgbox( "You must be using dBASE 9 or later "+;
	        "to run this form ...",;
			  "Wrong Version of dBASE", 16 )
   return
endif

// End of Line character:
#define EOL CHR( 13 ) + CHR( 10 ) 

LOCAL oSMTP, nErrors, cOutput
CLEAR
? "Start"
?
oSmtp = new OleAutoClient( "SocketTools.SmtpClient.8" )
oSmtp.SecureProtocol := 0

// insert your own server, port, username, and password
// here ...
cServer       = ""
nPort         = 0
cUsername     = ""
cPassword     = ""
// required -- may be set to false
bAuthenticate = true

if empty( cServer )
   msgbox( "Server information required!",;
           "Cannot Connect!", 16 )
   return
endif
if nPort == 0
   msgbox( "Port 0 not acceptable!",;
           "Cannot Connect!", 16 )
   return
endif
if empty( cUserName )
   msgbox( "User Name required!",;
           "Cannot Connect!", 16 )
   return
endif
if empty( cPassword )
   msgbox( "Password required!",;
           "Cannot Connect!", 16 )
   return
endif

if bAuthenticate
   // required for authentication
   oSMTP.Extended := true
endif

// parameters: server, port, username, password, timeout (seconds), options
//   If authentication is required, should use "1" for options, otherwise
//   use 0
nError = oSmtp.connect( cServer,;
                        nPort,;
                        cUserName,;
                        cPassword,;
                        120, ;
                        0 )
                        
IF nError > 0
   MSGBOX( "Connection error with server"+oSMTP.LastErrorString, "Error", 16 )
   oSmtp := null
   RETURN
else
   ? "Connection established"
   ? "oSMTP.isConnected: "+oSMTP.isConnected
ENDIF

// required for authentication:
if bAuthenticate
   // could force username/password, but not required, will
   // use defaults from connect
   nError = oSMTP.authenticate()
   IF nError > 0
      MSGBOX( "Authentication error with server"+oSMTP.LastErrorString, "Error", 16 )
      ? nError, oSMTP.LastErrorString
      oSMTP.disconnect()
      oSmtp := null
      RETURN
   else
      ? "Autentication achieved"
   ENDIF
endif // bAuthenticate

// use your own email for testing:
cFrom = ""
cTo   = ""
cSubject = ""
cMessage = "" // multiple lines can be added
              // using cMessage+= "more text"
              // for EOL use cMessage+= EOL
              // etc.
if empty( cFrom )
   msgbox( "From email address required!",;
           "Cannot Send!", 16 )
   return
endif
if empty( cTo )
   msgbox( "To email address required!",;
           "Cannot Send!", 16 )
   return
endif
if empty( cSubject )
   msgbox( "Subject address required!",;
           "Cannot Send!", 16 )
   return
endif
if empty( cMessage )
   msgbox( "Message body required!",;
           "Cannot Send!", 16 )
   return
endif

cOutput = ""
// MIME Header:
cOutput += "From: "+ cFrom + EOL
cOutput += "To: "+ cTo + EOL
// Date is put into the header by the control ...
//cOutput += "Date: "+ BuildDate() + EOL
cOutput += "Subject: " + cSubject + EOL
cOutput += "Content-Type: text/plain; charset=us-ascii" + EOL
cOutput += "Content-Transfer-Encoding: 7bit" + EOL
cOutput += "MIME-Version: 1.0" + EOL
// not required:
cOutput += "X-Mailer: TestSMTP 1.0" + EOL
cOutPut += EOL
// End of MIME Header

// BODY
cOutput += cMessage+EOL
// blank line required at end:
cOutput += EOL
// END OF BODY

? cOutput

nError := oSmtp.sendMessage( cFrom, cTo, cOutput )
?
? "Attempt to send message ..."
if nError > 0
   msgbox( "Error sending message: "+;
           oSMTP.LastErrorString, "Error", 16 )
   ? nError, oSMTP.lastErrorString           
endif

oSmtp.disconnect()
oSmtp := null
?
? "End"
